pub struct HttpBindingManifest {
pub binding_id: String,
pub method: i32,
pub path: String,
pub operation_name: Option<String>,
pub request_body_mode: i32,
pub response_body_mode: i32,
pub request_schema_json: Option<String>,
pub response_schema_json: Option<String>,
}Fields
binding_id: Stringmethod: i32path: Stringoperation_name: Option<String>request_body_mode: i32response_body_mode: i32request_schema_json: Option<String>response_schema_json: Option<String>Implementations
Sourceimpl HttpBindingManifest
impl HttpBindingManifest
Sourcepub fn method(&self) -> HttpMethod
pub fn method(&self) -> HttpMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: HttpMethod)
pub fn set_method(&mut self, value: HttpMethod)
Sets method to the provided enum value.
Sourcepub fn operation_name(&self) -> &str
pub fn operation_name(&self) -> &str
Returns the value of operation_name, or the default value if operation_name is unset.
Sourcepub fn request_body_mode(&self) -> HttpBodyMode
pub fn request_body_mode(&self) -> HttpBodyMode
Returns the enum value of request_body_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_request_body_mode(&mut self, value: HttpBodyMode)
pub fn set_request_body_mode(&mut self, value: HttpBodyMode)
Sets request_body_mode to the provided enum value.
Sourcepub fn response_body_mode(&self) -> HttpBodyMode
pub fn response_body_mode(&self) -> HttpBodyMode
Returns the enum value of response_body_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_response_body_mode(&mut self, value: HttpBodyMode)
pub fn set_response_body_mode(&mut self, value: HttpBodyMode)
Sets response_body_mode to the provided enum value.
Sourcepub fn request_schema_json(&self) -> &str
pub fn request_schema_json(&self) -> &str
Returns the value of request_schema_json, or the default value if request_schema_json is unset.
Sourcepub fn response_schema_json(&self) -> &str
pub fn response_schema_json(&self) -> &str
Returns the value of response_schema_json, or the default value if response_schema_json is unset.