pub struct OpenMeshStreamRequest {
pub stream_id: String,
pub target_peer_id: String,
pub plugin_id: String,
pub channel: String,
pub purpose: i32,
pub mode: i32,
pub bidirectional: bool,
pub content_type: Option<String>,
pub correlation_id: Option<String>,
pub metadata_json: Option<String>,
pub expected_bytes: Option<u64>,
pub idle_timeout_ms: Option<u64>,
}Fields
stream_id: Stringtarget_peer_id: Stringplugin_id: Stringchannel: Stringpurpose: i32mode: i32bidirectional: boolcontent_type: Option<String>correlation_id: Option<String>metadata_json: Option<String>expected_bytes: Option<u64>idle_timeout_ms: Option<u64>Implementations
Sourceimpl OpenMeshStreamRequest
impl OpenMeshStreamRequest
Sourcepub fn purpose(&self) -> StreamPurpose
pub fn purpose(&self) -> StreamPurpose
Returns the enum value of purpose, or the default if the field is set to an invalid enum value.
Sourcepub fn set_purpose(&mut self, value: StreamPurpose)
pub fn set_purpose(&mut self, value: StreamPurpose)
Sets purpose to the provided enum value.
Sourcepub fn mode(&self) -> StreamMode
pub fn mode(&self) -> StreamMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: StreamMode)
pub fn set_mode(&mut self, value: StreamMode)
Sets mode to the provided enum value.
Sourcepub fn content_type(&self) -> &str
pub fn content_type(&self) -> &str
Returns the value of content_type, or the default value if content_type is unset.
Sourcepub fn correlation_id(&self) -> &str
pub fn correlation_id(&self) -> &str
Returns the value of correlation_id, or the default value if correlation_id is unset.
Sourcepub fn metadata_json(&self) -> &str
pub fn metadata_json(&self) -> &str
Returns the value of metadata_json, or the default value if metadata_json is unset.
Sourcepub fn expected_bytes(&self) -> u64
pub fn expected_bytes(&self) -> u64
Returns the value of expected_bytes, or the default value if expected_bytes is unset.
Sourcepub fn idle_timeout_ms(&self) -> u64
pub fn idle_timeout_ms(&self) -> u64
Returns the value of idle_timeout_ms, or the default value if idle_timeout_ms is unset.