pub struct OpenMeshStreamResponse {
pub stream_id: String,
pub accepted: bool,
pub transport_kind: i32,
pub endpoint: Option<String>,
pub token: Option<String>,
pub expires_at_unix_ms: Option<u64>,
pub message: Option<String>,
}Fields
stream_id: Stringaccepted: booltransport_kind: i32endpoint: Option<String>token: Option<String>expires_at_unix_ms: Option<u64>message: Option<String>Implementations
Sourceimpl OpenMeshStreamResponse
impl OpenMeshStreamResponse
Sourcepub fn transport_kind(&self) -> StreamTransportKind
pub fn transport_kind(&self) -> StreamTransportKind
Returns the enum value of transport_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_transport_kind(&mut self, value: StreamTransportKind)
pub fn set_transport_kind(&mut self, value: StreamTransportKind)
Sets transport_kind to the provided enum value.
Sourcepub fn endpoint(&self) -> &str
pub fn endpoint(&self) -> &str
Returns the value of endpoint, or the default value if endpoint is unset.
Sourcepub fn token(&self) -> &str
pub fn token(&self) -> &str
Returns the value of token, or the default value if token is unset.
Sourcepub fn expires_at_unix_ms(&self) -> u64
pub fn expires_at_unix_ms(&self) -> u64
Returns the value of expires_at_unix_ms, or the default value if expires_at_unix_ms is unset.