pub struct PluginConfigControlAvailability {
pub enabled: bool,
pub reason: Option<String>,
pub note: Option<String>,
pub source: i32,
}Fields
enabled: boolreason: Option<String>note: Option<String>source: i32Implementations
Sourceimpl PluginConfigControlAvailability
impl PluginConfigControlAvailability
Sourcepub fn reason(&self) -> &str
pub fn reason(&self) -> &str
Returns the value of reason, or the default value if reason is unset.
Sourcepub fn source(&self) -> PluginConfigControlAvailabilitySource
pub fn source(&self) -> PluginConfigControlAvailabilitySource
Returns the enum value of source, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: PluginConfigControlAvailabilitySource)
pub fn set_source(&mut self, value: PluginConfigControlAvailabilitySource)
Sets source to the provided enum value.