pub struct PluginConfigControlBehavior {
pub numeric: Option<PluginConfigNumericControl>,
pub text_format: Option<i32>,
pub options_source: Option<i32>,
pub availability: Option<PluginConfigControlAvailability>,
pub enable_when: Vec<PluginConfigControlCondition>,
pub disable_when: Vec<PluginConfigConditionalDisable>,
pub conflicts: Vec<PluginConfigConflictRule>,
pub write_policy: Option<i32>,
}Fields
numeric: Option<PluginConfigNumericControl>text_format: Option<i32>options_source: Option<i32>availability: Option<PluginConfigControlAvailability>enable_when: Vec<PluginConfigControlCondition>disable_when: Vec<PluginConfigConditionalDisable>conflicts: Vec<PluginConfigConflictRule>write_policy: Option<i32>Implementations
Sourceimpl PluginConfigControlBehavior
impl PluginConfigControlBehavior
Sourcepub fn text_format(&self) -> PluginConfigTextFormat
pub fn text_format(&self) -> PluginConfigTextFormat
Returns the enum value of text_format, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_text_format(&mut self, value: PluginConfigTextFormat)
pub fn set_text_format(&mut self, value: PluginConfigTextFormat)
Sets text_format to the provided enum value.
Sourcepub fn options_source(&self) -> PluginConfigOptionsSource
pub fn options_source(&self) -> PluginConfigOptionsSource
Returns the enum value of options_source, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_options_source(&mut self, value: PluginConfigOptionsSource)
pub fn set_options_source(&mut self, value: PluginConfigOptionsSource)
Sets options_source to the provided enum value.
Sourcepub fn write_policy(&self) -> PluginConfigDisabledWritePolicy
pub fn write_policy(&self) -> PluginConfigDisabledWritePolicy
Returns the enum value of write_policy, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_write_policy(&mut self, value: PluginConfigDisabledWritePolicy)
pub fn set_write_policy(&mut self, value: PluginConfigDisabledWritePolicy)
Sets write_policy to the provided enum value.