pub struct PluginConfigPresentationManifest {
pub label: Option<String>,
pub help: Option<String>,
pub category_id: Option<String>,
pub category_label: Option<String>,
pub category_summary: Option<String>,
pub category_order: Option<u32>,
pub setting_order: Option<u32>,
pub unit: Option<String>,
pub placeholder: Option<String>,
pub control_hint: Option<String>,
pub renderer_id: Option<String>,
}Fields
label: Option<String>help: Option<String>category_id: Option<String>category_label: Option<String>category_summary: Option<String>category_order: Option<u32>setting_order: Option<u32>unit: Option<String>placeholder: Option<String>control_hint: Option<String>renderer_id: Option<String>Implementations
Sourceimpl PluginConfigPresentationManifest
impl PluginConfigPresentationManifest
Sourcepub fn label(&self) -> &str
pub fn label(&self) -> &str
Returns the value of label, or the default value if label is unset.
Sourcepub fn category_id(&self) -> &str
pub fn category_id(&self) -> &str
Returns the value of category_id, or the default value if category_id is unset.
Sourcepub fn category_label(&self) -> &str
pub fn category_label(&self) -> &str
Returns the value of category_label, or the default value if category_label is unset.
Sourcepub fn category_summary(&self) -> &str
pub fn category_summary(&self) -> &str
Returns the value of category_summary, or the default value if category_summary is unset.
Sourcepub fn category_order(&self) -> u32
pub fn category_order(&self) -> u32
Returns the value of category_order, or the default value if category_order is unset.
Sourcepub fn setting_order(&self) -> u32
pub fn setting_order(&self) -> u32
Returns the value of setting_order, or the default value if setting_order is unset.
Sourcepub fn placeholder(&self) -> &str
pub fn placeholder(&self) -> &str
Returns the value of placeholder, or the default value if placeholder is unset.
Sourcepub fn control_hint(&self) -> &str
pub fn control_hint(&self) -> &str
Returns the value of control_hint, or the default value if control_hint is unset.
Sourcepub fn renderer_id(&self) -> &str
pub fn renderer_id(&self) -> &str
Returns the value of renderer_id, or the default value if renderer_id is unset.