pub struct PluginConfigSchemaManifest {
pub plugin_name: String,
pub schema_version: u32,
pub allow_unvalidated_config: bool,
pub settings: Vec<PluginConfigSettingManifest>,
}Fields
plugin_name: Stringschema_version: u32allow_unvalidated_config: boolsettings: Vec<PluginConfigSettingManifest>Trait Implementations
Sourceimpl Clone for PluginConfigSchemaManifest
impl Clone for PluginConfigSchemaManifest
Sourcefn clone(&self) -> PluginConfigSchemaManifest
fn clone(&self) -> PluginConfigSchemaManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginConfigSchemaManifest
impl Debug for PluginConfigSchemaManifest
Sourceimpl Default for PluginConfigSchemaManifest
impl Default for PluginConfigSchemaManifest
Sourceimpl<'de> Deserialize<'de> for PluginConfigSchemaManifest
impl<'de> Deserialize<'de> for PluginConfigSchemaManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PluginConfigSchemaManifest> for ManifestEntry
impl From<PluginConfigSchemaManifest> for ManifestEntry
Sourcefn from(value: PluginConfigSchemaManifest) -> Self
fn from(value: PluginConfigSchemaManifest) -> Self
Converts to this type from the input type.
Sourceimpl Message for PluginConfigSchemaManifest
impl Message for PluginConfigSchemaManifest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for PluginConfigSchemaManifest