pub struct PluginConfigSettingManifest {
pub key: String,
pub value_schema: Option<PluginConfigValueSchema>,
pub required: bool,
pub default_json: Option<String>,
pub constraints: Vec<PluginConfigConstraintManifest>,
pub apply_mode: i32,
pub restart_scope: i32,
pub visibility: i32,
pub description: Option<String>,
pub presentation: Option<PluginConfigPresentationManifest>,
pub control_behavior: Option<PluginConfigControlBehavior>,
}Fields
key: Stringvalue_schema: Option<PluginConfigValueSchema>required: booldefault_json: Option<String>constraints: Vec<PluginConfigConstraintManifest>apply_mode: i32restart_scope: i32visibility: i32description: Option<String>presentation: Option<PluginConfigPresentationManifest>control_behavior: Option<PluginConfigControlBehavior>Implementations
Sourceimpl PluginConfigSettingManifest
impl PluginConfigSettingManifest
Sourcepub fn default_json(&self) -> &str
pub fn default_json(&self) -> &str
Returns the value of default_json, or the default value if default_json is unset.
Sourcepub fn apply_mode(&self) -> PluginConfigApplyMode
pub fn apply_mode(&self) -> PluginConfigApplyMode
Returns the enum value of apply_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_apply_mode(&mut self, value: PluginConfigApplyMode)
pub fn set_apply_mode(&mut self, value: PluginConfigApplyMode)
Sets apply_mode to the provided enum value.
Sourcepub fn restart_scope(&self) -> PluginConfigRestartScope
pub fn restart_scope(&self) -> PluginConfigRestartScope
Returns the enum value of restart_scope, or the default if the field is set to an invalid enum value.
Sourcepub fn set_restart_scope(&mut self, value: PluginConfigRestartScope)
pub fn set_restart_scope(&mut self, value: PluginConfigRestartScope)
Sets restart_scope to the provided enum value.
Sourcepub fn visibility(&self) -> PluginConfigVisibility
pub fn visibility(&self) -> PluginConfigVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: PluginConfigVisibility)
pub fn set_visibility(&mut self, value: PluginConfigVisibility)
Sets visibility to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.