pub struct PluginConfigValueSchema {
pub kind: i32,
pub enum_values: Vec<String>,
pub items: Option<Box<PluginConfigValueSchema>>,
pub object_properties: Vec<PluginConfigObjectProperty>,
pub allow_additional_properties: bool,
}Fields
kind: i32enum_values: Vec<String>items: Option<Box<PluginConfigValueSchema>>object_properties: Vec<PluginConfigObjectProperty>allow_additional_properties: boolImplementations
Sourceimpl PluginConfigValueSchema
impl PluginConfigValueSchema
Sourcepub fn kind(&self) -> PluginConfigValueKind
pub fn kind(&self) -> PluginConfigValueKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: PluginConfigValueKind)
pub fn set_kind(&mut self, value: PluginConfigValueKind)
Sets kind to the provided enum value.